==> peek_and_pop-0.1.8.tar.gz: CHANGELOG.md <==
## [0.1.8] - 18.08.2019

* Example project adapted to the updated [snap](https://pub.dev/packages/snap).

* Minor changes.

## [0.1.7] - 14.08.2019

* "Indicator" feature added. See this [video](https://youtu.be/wOWCV7HJzwc) for examples.

* Further improved performance.

* Further fine tuning for a smoother Peek & Pop process.

## [0.1.6] - 12.08.2019

* Missing documentation added.

* How-to-Use for README added.

* Fine tuning for a smoother Peek & Pop process.

* Some adjustments made for the Long Press version (still under development).

## [0.1.5] - 11.08.2019

* Improved performance.

* Improved code style.

## [0.1.4] - 11.08.2019

* Fixed a minor bug.

## [0.1.3] - 07.08.2019

* Fixed a bug in the example project.

* Improved installation directions: 
  
  **Note**: Don't forget to add <key>io.flutter.embedded_views_preview</key><string>YES</string> to your Info.plist. See
  [webview_flutter](https://pub.flutter-io.cn/packages/webview_flutter) for more info.

## [0.1.2] - 07.08.2019

* [snap](https://pub.dev/packages/snap) is now implemented directly to the example and it works flawlessly.

* More callbacks added for better control.

* Simple enumeration for stages.

* Improved animations.

* Improved documentation.

## [0.1.1] - 06.08.2019

* Improved code style.

## [0.1.0] - 06.08.2019

* Improved "PeekAndPopMoveController".

* Improved Long Press version.

* Improved documentation.

## [0.0.1] - 05.08.2019

* Initial release. Known issues are:

I) "For devices that don't support Force Press, the package comes with an adaptation to Long Press *however* the Long Press 
version of this package is still under development and is not fully tested yet so consider it as a developers preview."

II) "The "PeekAndPopMoveController" functionality is a very recent addition and therefore it can have unexpected behaviour. 
    An improved version will be submitted shortly."

==> peek_and_pop-0.1.9.tar.gz: CHANGELOG.md <==
## [0.1.9] - 20.08.2019

* Modifications to Flutter's normal "binding.dart" are no longer required!

* The Long Press version is temporarily removed. It will be added back with the next update.

* Code excerpt added to the README.

* Updated the README.

## [0.1.8] - 18.08.2019

* Example project adapted to the updated [snap](https://pub.dev/packages/snap).

* Minor changes.

* [0.1.8+1] An important notice added to the README.

## [0.1.7] - 14.08.2019

* The "Indicator" feature added. See this [video](https://youtu.be/wOWCV7HJzwc) for examples.

* Further improved performance.

* Further fine tuning for a smoother Peek & Pop process.

## [0.1.6] - 12.08.2019

* Missing documentation added.

* How-to-Use added to the README.

* Fine tuning for a smoother Peek & Pop process.

* Improved Long Press version (still under development).

## [0.1.5] - 11.08.2019

* Improved performance.

* Improved code style.

## [0.1.4] - 11.08.2019

* Fixed a minor bug.

## [0.1.3] - 07.08.2019

* Fixed a minor bug in the example project.

* Improved installation instructions: 
  
  **Note**: Don't forget to add <key>io.flutter.embedded_views_preview</key><string>YES</string> to your Info.plist. See
  [webview_flutter](https://pub.flutter-io.cn/packages/webview_flutter) for more info.

## [0.1.2] - 07.08.2019

* [snap](https://pub.dev/packages/snap) is now implemented directly to the example.

* More callbacks added for better control.

* Simple enumeration for stages added.

* Improved animations.

* Improved documentation.

## [0.1.1] - 06.08.2019

* Improved code style.

## [0.1.0] - 06.08.2019

* Improved PeekAndPopMoveController.

* Improved Long Press version (still under development).

* Improved documentation.

## [0.0.1] - 05.08.2019

* Initial release. Known issues are:

I) "For devices that don't support Force Press, the package comes with an adaptation to Long Press *however* the Long Press 
version of this package is still under development and is not fully tested yet so consider it as a developers preview."

II) "The "PeekAndPopMoveController" functionality is a very recent addition and therefore it can have unexpected behaviour. 
    An improved version will be submitted shortly."
